@@ -443,7 +443,7 @@ int main(int argc, const char* argv[])
 		FilterTagsByExpression<string, string> filterByExpression("");
 		if (opts.get("remove-tags").defined())
 		{
-			filterByExpression.setExpression(opts.get("remove-tags").stringVal()); 
+			filterByExpression.setExpression(not Expression(opts.get("remove-tags").stringVal())); 
 			filters.appendFilter(filterByExpression);
 		}
 
